@@ -18,9 +18,10 @@ See http://wiki.opscode.com/display/chef/Anatomy+of+a+Chef+Run
 import os
 import shutil
 import simplejson as json
+from copy import deepcopy
 
 from fabric.api import *
-from fabric.contrib.files import append, exists
+from fabric.contrib.files import exists
 from fabric import colors
 from fabric.utils import abort
 from fabric.contrib.project import rsync_project
@@ -121,11 +122,24 @@ def _synchronize_node(configfile, node):
     # Remove local temporary node file
     os.remove(configfile)
     # Synchronize kitchen
+    extra_opts = "-q"
+    if env.follow_symlinks:
+        extra_opts += " --copy-links"
+    ssh_opts = ""
+    if env.ssh_config_path:
+        ssh_opts += " -F %s" % env.ssh_config_path
+    if env.encrypted_data_bag_secret:
+        put(env.encrypted_data_bag_secret,
+            "/etc/chef/encrypted_data_bag_secret",
+            use_sudo=True,
+            mode=0600)
+        sudo('chown root:root /etc/chef/encrypted_data_bag_secret')
     rsync_project(
         env.node_work_path, './cookbooks ./data_bags ./roles ./site-cookbooks',
         exclude=('*.svn', '.bzr*', '.git*', '.hg*'),
         delete=True,
-        extra_opts="-q",
+        extra_opts=extra_opts,
+        ssh_opts=ssh_opts
     )
     _add_search_patch()
 
@@ -143,7 +157,7 @@ def build_dct(dic, keys, value):
         elif value == "true":
             value = True
         # It's a leaf, assign value
-        dic[key] = value
+        dic[key] = deepcopy(value)
 
 
 def update_dct(dic1, dic2):
@@ -211,7 +225,7 @@ def _add_merged_attributes(node, all_recipes, all_roles):
     for role in node['roles']:
         for r in all_roles:
             if role == r['name']:
-                update_dct(attributes, r['default_attributes'])
+                update_dct(attributes, r.get('default_attributes', {}))
 
     # Get normal node attributes
     non_attribute_fields = [
@@ -227,7 +241,7 @@ def _add_merged_attributes(node, all_recipes, all_roles):
     for role in node['roles']:
         for r in all_roles:
             if role == r['name']:
-                update_dct(attributes, r['override_attributes'])
+                update_dct(attributes, r.get('override_attributes', {}))
     # Merge back to the original node object
     node.update(attributes)
 
@@ -311,6 +325,8 @@ def _node_cleanup():
             _remove_remote_node_data_bag()
             with settings(warn_only=True):
                 sudo("rm '/etc/chef/node.json'")
+                if env.encrypted_data_bag_secret:
+                    sudo("rm '/etc/chef/encrypted_data_bag_secret'")
 
 
 def _add_search_patch():
