@@ -63,6 +63,7 @@ def new_kitchen():
             print >> configfh, "password = "
             print >> configfh, "keypair-file = "
             print >> configfh, "ssh-config = "
+            print >> configfh, "encrypted_data_bag_secret = "
             print >> configfh, "[kitchen]"
             print >> configfh, "node_work_path = /tmp/chef-solo/"
             print "config.cfg file created..."
@@ -125,6 +126,8 @@ def node(*nodes):
         for hostname in env.hosts:
             env.host = hostname
             env.host_string = hostname
+            if '@' in hostname:
+                env.user = hostname.split('@')[0]
             node = lib.get_node(env.host)
             lib.print_header("Configuring {0}".format(env.host))
             if __testing__:
@@ -229,7 +232,8 @@ def plugin(name):
     if not env.host_string:
         abort('No node specified\nUsage: fix node:MYNODES plugin:MYPLUGIN')
     plug = lib.import_plugin(name)
-    print("Executing plugin '{0}' on {1}".format(name, env.host_string))
+    lib.print_header("Executing plugin '{0}' on "
+                     "{1}".format(name, env.host_string))
     node = lib.get_node(env.host_string)
     if node == {'run_list': []}:
         node['name'] = env.host_string
@@ -346,8 +350,11 @@ def _readconfig():
 
     if ssh_config:
         env.ssh_config = _SSHConfig()
+        env.ssh_config_path = os.path.expanduser(ssh_config)
+        env.use_ssh_config = True
+
         try:
-            env.ssh_config.parse(open(os.path.expanduser(ssh_config)))
+            env.ssh_config.parse(open(env.ssh_config_path))
         except IOError:
             msg = "Couldn't open the ssh-config file '{0}'".format(ssh_config)
             abort(msg)
@@ -355,6 +362,23 @@ def _readconfig():
             msg = "Couldn't parse the ssh-config file '{0}'".format(ssh_config)
             abort(msg)
 
+    # Check for an encrypted_data_bag_secret file and set the env option
+    env.encrypted_data_bag_secret = None
+    try:
+        encrypted_data_bag_secret = config.get('userinfo',
+            'encrypted_data_bag_secret')
+    except ConfigParser.NoOptionError:
+        encrypted_data_bag_secret = None
+
+    if encrypted_data_bag_secret:
+        env.edbs_path = os.path.expanduser(encrypted_data_bag_secret)
+        try:
+            open(env.edbs_path)
+        except IOError as e:
+            msg = "Failed to open encrypted_data_bag_secret file at '{0}'".format(env.edbs_path)
+            abort(msg)
+        env.encrypted_data_bag_secret = env.edbs_path
+
     try:
         env.user = config.get('userinfo', 'user')
         user_specified = True
@@ -389,6 +413,12 @@ def _readconfig():
         if not env.node_work_path:
             abort('The "node_work_path" option cannot be empty')
 
+    # Follow symlinks
+    try:
+        env.follow_symlinks = config.getboolean('kitchen', 'follow_symlinks')
+    except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
+        env.follow_symlinks = False
+
 
 # Only read config if fix is being used and we are not creating a new kitchen
 env.chef_environment = littlechef.chef_environment
